using FlexCel.Pdf;
using FlexCel.Render;
using FlexCel.Report;
using FlexCel.XlsAdapter;
using System.Reflection;

namespace AndroidFlexcelTestApp
{
   [Activity(Label = "@string/app_name", MainLauncher = true)]
   public class MainActivity : Activity
   {
      protected override void OnCreate(Bundle? savedInstanceState)
      {
         base.OnCreate(savedInstanceState);
         SetContentView(Resource.Layout.activity_main);

         Button coldstartbutton = FindViewById<Button>(Resource.Id.coldstartbutton);
         coldstartbutton.Click += ColdStartButtonOnClick;
      }

      private void ColdStartButtonOnClick(object sender, EventArgs eventArgs)
      {
         ColdStart();
      }

      private void ColdStart()
      {
         Assembly assembly = Assembly.GetExecutingAssembly();
         bool startedSuccessfully = true;
         using (Stream coldStartTemplateStream = assembly.GetManifestResourceStream("AndroidFlexcelTestApp.Resources.result.xlsx"))
         {
            using (MemoryStream flexCelReportResultStream = new MemoryStream())
            {
               XlsFile xls = null;
               try
               {
                  using (FlexCelReport fr = new FlexCelReport(true))
                  {
                     fr.Run(coldStartTemplateStream, flexCelReportResultStream);
                     flexCelReportResultStream.Position = 0;

                     xls = new XlsFile(true);
                     string pathToSave = Path.Combine(GetExternalFilesDir(null).AbsolutePath, "result.xlsx");
                     xls.Open(flexCelReportResultStream);
                     xls.Save(pathToSave);
                  }
               }
               catch (Exception e)
               {
                  startedSuccessfully = false;
               }

               if (xls != null && startedSuccessfully)
               {
                  startedSuccessfully = MakeInMemoryPdf(xls);
               }
            }
         }

         if (startedSuccessfully)
         {
         }
      }

      private bool MakeInMemoryPdf(XlsFile xls)
      {
         bool result = true;
         string pathToSave = Path.Combine(GetExternalFilesDir(null).AbsolutePath, "result.pdf");
         using (FlexCelPdfExport pdf = new FlexCelPdfExport(xls, true))
         {
            pdf.FontMapping = TFontMapping.DontReplaceFonts;
            pdf.GetFontFolder += PdfOnGetFontFolder;
            pdf.FontEmbed = TFontEmbed.Embed;
            pdf.FallbackFonts = "Noto Sans;Noto Sans Arabic UI;Noto Sans Armenian;Noto Sans Bengali UI;Noto Sans Coptic;Noto Sans Devanagari UI;Noto Sans Georgian;Noto Sans Gujarati UI;Noto Sans Gurmukhi UI;Noto Sans Hebrew;Noto Sans Kannada UI;Noto Sans Khmer UI;Noto Sans Lao UI;Noto Sans Malayalam UI;Noto Sans Mongolian;Noto Sans Myanmar UI;Noto Sans Oriya UI;Noto Sans Tamil UI;Noto Sans Telugu UI;Noto Sans Thai UI;Droid Sans Fallback;Noto Sans Korean Regular";
            pdf.Export(pathToSave);
         }

         return result;
      }

      private void PdfOnGetFontFolder(object sender, GetFontFolderEventArgs e)
      {
         
      }

      private void PdfOnGetFontData(object sender, GetFontDataEventArgs e)
      {
         
      }
   }
}